@@ -38,15 +38,18 @@ class Query:
 
         self._timeframe = _timeframe
 
-    def execute(self, skip=0, sort="descending"):
+    def execute(self, skip=0, sort=None):
         if not self._query:
             raise InvalidQueryError("Missing query.")
 
+        if not sort:
+            sort = ["timestamp", "descending"]
+
         if skip > 90:
             raise InvalidQueryError("Skip limit is 90.")
 
-        if sort not in ["descending", "ascending"]:
-            raise InvalidQueryError("Sort can only be 'descending' or 'ascending'.")
+        if not isinstance(sort, list):
+            raise InvalidQueryError("Sort condition must be passed as a list with the format: [key, order].")
 
         method_endpoint = "/query"
         payload = {
