@@ -1,5 +1,5 @@
 from chaingrep.api_resources.requester import Requester
-from chaingrep.exceptions import InvalidTransactionHashError, TransactionParsingError
+from chaingrep.exceptions import InvalidTransactionHashError, TransactionParsingError, TransactionSimulationError
 
 
 class Transaction:
@@ -27,3 +27,21 @@ class Transaction:
             raise TransactionParsingError(f"{response}.")
 
         return response
+
+
+class RawTransaction:
+    def __init__(self, raw_transaction, auth):
+        self.raw_transaction = dict(raw_transaction)
+        self.auth = auth
+
+    def simulate(self):
+        method_endpoint = "/transaction/simulation"
+        response = Requester(self.auth).post(method_endpoint, body=self.raw_transaction)
+
+        status_code = response.get("status_code")
+        response = response.get("response")
+
+        if status_code != 200:
+            raise TransactionSimulationError(response)
+
+        return response
